{% load i18n %}

<div class='left'>
    <fieldset>
    {% include 'horizon/common/_form_fields.html' %}
    </fieldset>
</div>
<div class='right'>
    <h3>{% trans 'Description:' %}</h3>
    <p>
        <strong>{% trans 'Environment Name'  %}:</strong>
        {% blocktrans %}Create a name for the environment{% endblocktrans %}
    </p>
    <p>
        {% blocktrans %} An environment is a collection of instances that 
        are meant to operate under similar conditions.{% endblocktrans %}
    </p>

</div>
