{% extends 'common/_modal_form.html' %}
{% load i18n %}
{% load url from future %}

{% block form_id %}add_category_form{% endblock %}
{% block form_attrs %}enctype='multipart/form-data'{% endblock %}
{% block form_action %}{% url 'horizon:murano:categories:add' %}{% endblock %}
{% block modal-header %}{% trans 'Add Application Category' %}{% endblock %}
{% block modal_id %}add_category_form{% endblock %}
{% block modal-body %}
<div class='left'>
    <fieldset>
    {% include 'horizon/common/_form_fields.html' %}
    </fieldset>
</div>
<div class='right'>
    <h3>{% trans 'Description:' %}</h3>
    <p>{% trans 'Add new category to the application catalog. ' %}</p>
    <p>
        <strong>{% trans 'Name'  %}:</strong>
        {% blocktrans %}Provide desired name for a new category{% endblocktrans %}
    </p>

</div>
{% endblock %}

{% block modal-footer %}
  <input class='btn btn-primary pull-right' type='submit' value='{% trans 'Add' %}' />
      <a href="{% url 'horizon:murano:categories:index' %}" class="btn secondary cancel close">{% trans "Cancel" %}</a>
{% endblock %}
