{% load i18n %}

<h3>{% trans 'Description:' %}</h3>
<p>{% blocktrans %}<strong>Name:</strong> Created for identifying a package.{% endblocktrans %}</p>
<p>{% blocktrans %}<strong>Tags:</strong> Used for identifying and filtering packages.{% endblocktrans %}</p>
<p>{% blocktrans %}<strong>Public:</strong> Defines whether or not a package is available for use by other tenants. (Applies to package dependencies){% endblocktrans %}</p>
<p>{% blocktrans %}<strong>Active:</strong> Allows the status of a package to be changed. (Applies to package dependencies){% endblocktrans %}</p>
<p>{% blocktrans %}<strong>Description:</strong> Allows additional information to be added about a package.{% endblocktrans %}</p>
