{% extends 'common/_modal_form.html' %}
{% load i18n %}
{% load url from future %}

{% block form_id %}create_environment_form{% endblock %}
{% block form_attrs %}enctype='multipart/form-data'{% endblock %}
{% block form_action %}{% url 'horizon:murano:environments:create_environment' %}{% endblock %}
{% block modal-header %}{% trans 'Create Environment' %}{% endblock %}
{% block modal_id %}create_environment_form{% endblock %}
{% block modal-body %}
    {% include "environments/_fields.html" %}
{% endblock %}

{% block modal-footer %}
  <input class='btn btn-primary pull-right' type='submit' value='{% trans 'Create' %}' />
      <a href='{% url 'horizon:murano:environments:index' %}' class='btn secondary cancel close'>{% trans 'Cancel' %}</a>
{% endblock %}
