{% extends 'common/_modal_form.html' %}
{% load i18n %}
{% load url from future %}

{% block form_id %}update_environment_form{% endblock %}
{% block form_attrs %}enctype='multipart/form-data'{% endblock %}
{% block form_action %}{% url 'horizon:murano:environments:update_environment' env_id %}{% endblock %}
{% block modal-header %}{% trans 'Edit Environment' %}{% endblock %}
{% block modal_id %}update_environment_form{% endblock %}
{% block modal-body %}
    {% include "environments/_fields.html" %}
{% endblock %}

{% block modal-footer %}
  <input class='btn btn-primary pull-right' type='submit' value='{% trans 'Edit' %}' />
      <a href="{% url 'horizon:murano:environments:index' %}" class="btn secondary cancel close">{% trans "Cancel" %}</a>
{% endblock %}
